@@ -298,7 +298,7 @@ use Gtk2;
         
         foreach (@{$movies})
         {
-            next if ($_->{borrower} eq 'none');
+            next if (!$_->{borrower}) || ($_->{borrower} eq 'none');
             my @infos = [ $_->{title}, $_->{borrower}, $_->{lendDate} ];
             push @{$self->{movies}->{data}}, @infos;
         }
@@ -471,7 +471,8 @@ use Gtk2;
                         'error',
                         'ok',
                         $self->{parent}->{lang}->{MailSendmailError}."\n\n$!");
-                    
+
+                $dialog->set_position('center-on-parent');
                 $dialog->run;
                 $dialog->destroy;               
             }
@@ -486,7 +487,8 @@ use Gtk2;
                         'error',
                         'ok',
                         $self->{parent}->{lang}->{MailSmtpError});
-                    
+                  
+                $dialog->set_position('center-on-parent');  
                 $dialog->run;
                 $dialog->destroy;
                 return;
