@@ -257,7 +257,7 @@ use strict;
         return $info;
     }
 
-    sub setPanel()
+    sub setPanel
     {
         my ($self, $panel) = @_;
         $self->{panel} = $panel;
@@ -343,6 +343,20 @@ use strict;
             if  $info->{collection}
             && ($info->{rank} > $self->{maxRanks}->{$info->{collection}});
                 
+        #Propagate borrowing information
+        if (($info->{collection})
+         && ($self->{minRanks}->{$info->{collection}} >= $info->{rank})
+         && ($info->{borrower} ne $previous->{borrower}))
+        {
+            for (my $i = 0; $i < $self->{nbMovies}; $i++)
+            {
+                next if $self->{movieArray}[$i]->{collection} ne $info->{collection};
+                $self->{movieArray}[$i]->{borrower} = $info->{borrower};
+                $self->{movieArray}[$i]->{lendDate} = $info->{lendDate};
+            }
+        }
+
+
         if (($oldTitle ne $self->{movieArray}[$self->{currentMovie}]->{title}) &&
             ($self->{currentSortField} eq 'title'))
         {
@@ -1093,10 +1107,10 @@ use strict;
         return if (!$file);
         if (! -e $file)
 		{
-		    $self->{nbMovies} = 0;
-		    $self->{panel}->hide;
-	            open MOVIES, ">$file" or die "Cannot create $file\n";
-	            close MOVIES;
+            $self->{nbMovies} = 0;
+            $self->{panel}->hide if $self->{panel};
+            open MOVIES, ">$file" or die "Cannot create $file\n";
+            close MOVIES;
 		}
 		if (! open MOVIES, "<$file")
 		{
