@@ -317,6 +317,40 @@ my $hasAboutDialog = ($@ ? 0 : 1);
     }
 }
 
+{
+    package GCImageDialog;
+    use base "Gtk2::Dialog";
+
+    sub show
+    {
+        my $self = shift;
+        $self->SUPER::show();
+        $self->show_all;
+        my $code = $self->run;
+        $self->hide;
+    }
+
+    sub new
+    {
+        my ($proto, $parent, $file) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($parent->{lang}->{ImportViewPicture},
+                              $parent,
+                              [qw/modal destroy-with-parent/],
+                              'gtk-ok' => 'ok'
+                              );
+        bless($self, $class);
+
+        $self->{parent} = $parent;
+
+        my $image = Gtk2::Image->new_from_file($file);
+        $self->vbox->pack_start($image,0,0,0);
+
+        return $self;
+    }
+}
+
+
 {
     package GCDateSelectionDialog;
     use base "Gtk2::Dialog";
