@@ -23,7 +23,9 @@ package GCDisplay;
 ###################################################
 
 use strict;
+use GCUtils;
 
+my $firstYear = 1895;
 
 {
     package GCFilterSearch;
@@ -46,6 +48,8 @@ use strict;
     {
         my $self = shift;
         
+        $self->{cleared} = 1;
+        
         $self->{info} = {
                         seen => -1,
                         title => '',
@@ -57,14 +61,16 @@ use strict;
                         rating => 0,
                         age => -1,
                         audio => '',
-                        subt => ''
+                        subt => '',
+                        yearMin => $firstYear,
+                        yearMax => 9999
                         };
     }
 
     sub setOptions
     {
         my ($self, $info) = @_;
-        
+        $self->{cleared} = 0;
         $self->{info} = $info;
     }
 
@@ -72,6 +78,7 @@ use strict;
     {
         my ($self, $seen) = @_;
         
+        $self->{cleared} = 0;
         $self->{info}->{seen} = $seen;
     }
     
@@ -79,6 +86,7 @@ use strict;
     {
         my ($self, $rating) = @_;
         
+        $self->{cleared} = 0;
         $self->{info}->{rating} = $rating;
     }
     
@@ -86,6 +94,7 @@ use strict;
     {
         my ($self, $rating) = @_;
         
+        $self->{cleared} = 0;
         $self->{info}->{age} = $rating;
     }
     
@@ -93,6 +102,7 @@ use strict;
     {
         my ($self, $borrowing) = @_;
         
+        $self->{cleared} = 0;
         $self->{info}->{borrowed} = $borrowing;
     }
     
@@ -100,6 +110,7 @@ use strict;
     {
         my ($self, $type) = @_;
         
+        $self->{cleared} = 0;
         $self->{info}->{type} = $type;
     }
 
@@ -107,10 +118,12 @@ use strict;
     {
         my ($self, $info) = @_;
 
+        return 1 if $self->{cleared};
+
         return 0 if ($self->{info}->{seen} != -1) && ($info->{seen} != $self->{info}->{seen});
         return 0 if $self->{info}->{title} && ($info->{title} !~ m/$self->{info}->{title}/i);
         return 0 if $self->{info}->{director} && ($info->{director} !~ m/$self->{info}->{director}/i);
-        return 0 if $self->{info}->{type} && ($info->{type} !~ m/$self->{info}->{type}/i);
+        return 0 if $self->{info}->{type} && ($info->{type} !~ m/$self->{info}->{type}(,|$)/i);
 
         return 0 if $self->{info}->{audio} && ($info->{audio} !~ m/$self->{info}->{audio}/i);
         return 0 if $self->{info}->{subt} && ($info->{subt} !~ m/$self->{info}->{subt}/i);
@@ -135,7 +148,12 @@ use strict;
                 return 0 if $info->{actors} !~ /$_/i;
             }
         }
-                
+        my $year = GCUtils::extractYear($info->{date});
+        return 0 if !$year && $self->{info}->{yearMin} && ($self->{info}->{yearMin} != $firstYear);
+        return 0 if ($year) &&
+                (($year < $self->{info}->{yearMin})
+              || ($year > $self->{info}->{yearMax}));
+
         return 1;
     }
 }
@@ -281,17 +299,17 @@ use Gtk2;
         $self->{borrowerOption}->remove_menu;
         $self->{borrowerOption}->set_menu($self->{borrower});
                 
-        $self->{age}->setValue($info->{age});
+        $self->{age}->set_text($info->{age});
     }
     
     sub show
     {
         my $self = shift;
         
-        $self->setTypes($self->{parent}->{movies}->getTypes);
+        $self->setTypes($self->{parent}->{movies}->getHistory('type'));
 
-        $self->setAudios($self->{parent}->{movies}->getAudios);
-        $self->setSubs($self->{parent}->{movies}->getSubs);
+        $self->setAudios($self->{parent}->{movies}->getHistory('audio'));
+        $self->setSubts($self->{parent}->{movies}->getHistory('subt'));
         
         my @borrowers = split m/\|/, $self->{parent}->{options}->borrowers;
         $self->setBorrowers(\@borrowers);
@@ -310,11 +328,17 @@ use Gtk2;
                 my %info;
             
                 $info{title} = $self->{title}->get_text;
-                $info{rating} = $self->{rating}->get_value;
                 $info{director} = $self->{director}->get_text;
-                $info{actors} = $self->{actors}->get_text;
-
                 $info{type} = ($self->{type}->get_children)[0]->get_text;
+                $info{actors} = $self->{actors}->get_text;
+                $info{age} = $self->{age}->get_text;
+                $info{yearMin} = $self->{yearMin}->get_value;
+                $info{yearMax} = $self->{yearMax}->get_value;
+
+                $info{audio} = $self->{audioOption}->child->get_label;
+                $info{subt} = $self->{subtOption}->child->get_label;
+                $self->{previousAudio} = $info{audio};
+                $self->{previousSubt} = $info{subt};
             
                 my $seen = -1;
                 foreach (@{$self->{seen}})
@@ -323,19 +347,12 @@ use Gtk2;
                     $seen++;
                 }
                 $info{seen} = $seen;
-
+                $info{rating} = $self->{rating}->get_value;
+                
                 $info{borrower} = $self->{borrowerOption}->child->get_label;
                 $info{borrower} =  'none' if $self->{borrowerOption}->child->get_label eq $self->{parent}->{lang}->{PanelNobody};
                 $info{borrowed} = -1;
 
-                $info{audio} = $self->{audioOption}->child->get_label;
-                $info{subt} = $self->{subtOption}->child->get_label;
-
-                $self->{previousAudio} = $info{audio};
-                $self->{previousSubt} = $info{subt};
-
-                $info{age} = $self->{age}->getValue;
-
                 $self->{parent}->{menubar}->initFilters(
                                                         $info{seen},
                                                         $info{borrower},
@@ -357,24 +374,26 @@ use Gtk2;
         my $self = shift;
         
         $self->{title}->set_text('');
-        $self->{rating}->set_value(0);
         $self->{director}->set_text('');
+        ($self->{type}->get_children)[0]->set_text('');
         $self->{actors}->set_text('');
-        $self->{seen}[0]->set_active(1);
-        
-        $self->{borrowerOption}->remove_menu;
-        $self->{borrower}->set_active(0) if $self->{borrower};
-        $self->{borrowerOption}->set_menu($self->{borrower}) if $self->{borrower};
+        $self->{age}->set_text(0);
+        $self->{yearMin}->set_value($self->{firstYear});
+        $self->{yearMax}->set_value($self->{currentYear});
 
         $self->{audioOption}->remove_menu;
         $self->{audio}->set_active(0) if $self->{audio};
         $self->{audioOption}->set_menu($self->{audio}) if $self->{audio};
-
         $self->{subtOption}->remove_menu;
         $self->{subt}->set_active(0) if $self->{subt};
         $self->{subtOption}->set_menu($self->{subt}) if $self->{subt};
-        
-        ($self->{type}->get_children)[0]->set_text('');
+
+        $self->{seen}[0]->set_active(1);
+        $self->{rating}->set_value(0);
+
+        $self->{borrowerOption}->remove_menu;
+        $self->{borrower}->set_active(0) if $self->{borrower};
+        $self->{borrowerOption}->set_menu($self->{borrower}) if $self->{borrower};
     }
     
     sub search
@@ -438,7 +457,7 @@ use Gtk2;
         $self->{audioOption}->show_all;
     }
     
-    sub setSubs
+    sub setSubts
     {
         my ($self, $values) = @_;
         
@@ -475,64 +494,113 @@ use Gtk2;
                               );
 
         $self->{parent} = $parent;
-                              
-        my $table = new Gtk2::Table(13,2,0);
-        $table->set_row_spacings(10);
+
+        #my $header = new GCDialogHeader($parent->{lang}->{SearchTitle}, 'find', $parent->{logosDir});
+        #$self->vbox->pack_start($header, 0, 0, 0);
+
+        my $table = new Gtk2::Table(14,2,0);
+        $table->set_row_spacings(5);
         $table->set_col_spacings(10);
         $table->set_border_width(20);
-                              
+
+        my $row = 0;
+
         my $titleLabel = new Gtk2::Label($parent->{lang}->{SearchMovieTitle});
         $titleLabel->set_alignment(0,0.5);
         $self->{title} = new Gtk2::Entry;
         $self->{title}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($titleLabel, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
-        $table->attach($self->{title}, 1, 2, 0, 1, 'fill', 'expand', 0, 0);
+        $table->attach($titleLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{title}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
+
+        $row++;
 
         my $directorLabel = new Gtk2::Label($parent->{lang}->{SearchDirector});
         $directorLabel->set_alignment(0,0.5);
         $self->{director} = new Gtk2::Entry;
         $self->{director}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($directorLabel, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
-        $table->attach($self->{director}, 1, 2, 1, 2, 'fill', 'expand', 0, 0);
+        $table->attach($directorLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{director}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
+
+        $row++;
 
         my $typeLabel = new Gtk2::Label($parent->{lang}->{SearchType});
         $typeLabel->set_alignment(0,0.5);
         $self->{type} = Gtk2::Combo->new;
         ($self->{type}->get_children)[0]->set_editable(0);
-        $table->attach($typeLabel, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
-        $table->attach($self->{type}, 1, 2, 2, 3, 'fill', 'expand', 0, 0);
+        $table->attach($typeLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{type}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
+        
+        $row++;
         
         my $actorsLabel = new Gtk2::Label($parent->{lang}->{SearchActors});
         $actorsLabel->set_alignment(0,0.5);
         $self->{actors} = new Gtk2::Entry;
         $self->{actors}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($actorsLabel, 0, 1, 3, 4, 'fill', 'fill', 0, 0);
-        $table->attach($self->{actors}, 1, 2, 3, 4, 'fill', 'expand', 0, 0);
+        $table->attach($actorsLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{actors}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
+
+        $row++;
 
         my $ageLabel = new Gtk2::Label($parent->{lang}->{SearchAge});
         $ageLabel->set_alignment(0,0.5);
         $self->{age} = new GCAgeChooser($parent->{lang}, 'public',150);
-        $table->attach($ageLabel, 0, 1, 4, 5, 'fill', 'fill', 0, 0);
-        $table->attach($self->{age}, 1, 2, 4, 5, 'fill', 'fill', 0, 0);
+        $table->attach($ageLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{age}, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
 
-        $table->attach(Gtk2::HSeparator->new, 0, 2, 5, 6, 'fill', 'fill', 0, 0);
+        $row++;
 
-        my $audioLabel = new Gtk2::Label($parent->{lang}->{PanelAudio});
+        my $yearLabel = new Gtk2::Label($parent->{lang}->{SearchYear});
+        $yearLabel->set_alignment(0,0.5);
+        my $betweenYearLabel = new Gtk2::Label($parent->{lang}->{SearchYearBetween});
+        $self->{firstYear} = $firstYear;
+        my $adjYear1 = Gtk2::Adjustment->new($self->{firstYear}, $self->{firstYear}, 9999, 1, 10, 0) ;
+        $self->{yearMin} = Gtk2::SpinButton->new($adjYear1, 0, 0);
+        $self->{yearMin}->set_numeric(1);
+        $self->{yearMin}->signal_connect('activate' => sub {$self->response('ok')} );
+        my ($secondes, $minutes, $hours, $day, $month, $year) = localtime;
+        $self->{currentYear} = $year + 1900;
+        my $adjYear2 = Gtk2::Adjustment->new($self->{currentYear}, $self->{firstYear}, 9999, 1, 10, 0) ;
+        $self->{yearMax} = Gtk2::SpinButton->new($adjYear2, 0, 0);
+        $self->{yearMax}->set_numeric(1);
+        $self->{yearMax}->signal_connect('activate' => sub {$self->response('ok')} );
+        $self->{yearBox} = new Gtk2::HBox(0,0);
+        $self->{yearBox}->pack_start($self->{yearMin},1,1,0);
+        $self->{yearBox}->pack_start($betweenYearLabel,1,1,20);
+        $self->{yearBox}->pack_start($self->{yearMax},1,1,0);
+        $table->attach($yearLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{yearBox}, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+
+        $row++;
+
+        $table->attach(Gtk2::HSeparator->new, 0, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+
+        $row++;
+
+        my $audioLabel = new Gtk2::Label($parent->{lang}->{Displayed}->{audio});
+        $audioLabel->set_alignment(0,0.5);
         $self->{audioOption} = new Gtk2::OptionMenu();
         $self->{audioOption}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($audioLabel, 0, 1, 6, 7, 'fill', 'fill', 0, 0);
-        $table->attach($self->{audioOption}, 1, 2, 6, 7, 'fill', 'expand', 0, 0);
+        $table->attach($audioLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{audioOption}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
 
-        my $subLabel = new Gtk2::Label($parent->{lang}->{PanelSub});
+        $row++;
+
+        my $subLabel = new Gtk2::Label($parent->{lang}->{Displayed}->{subt});
+        $subLabel->set_alignment(0,0.5);
         $self->{subtOption} = new Gtk2::OptionMenu();
         $self->{subtOption}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($subLabel, 0, 1, 7, 8, 'fill', 'fill', 0, 0);
-        $table->attach($self->{subtOption}, 1, 2, 7, 8, 'fill', 'expand', 0, 0);
+        $table->attach($subLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{subtOption}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
 
-        $table->attach(Gtk2::HSeparator->new, 0, 2, 8, 9, 'fill', 'fill', 0, 0);
+        $row++;
+
+        $table->attach(Gtk2::HSeparator->new, 0, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+        
+        $row++;
         
         my $hboxSeen = new Gtk2::HBox(0,0);
         my $labelSeen = new Gtk2::Label($parent->{lang}->{SearchSeen});
+        $labelSeen->set_alignment(0,0.5);
 		$self->{seen}[0] = new  Gtk2::RadioButton(undef,$parent->{lang}->{SearchUndef});
 		my $seenGroup = $self->{seen}[0]->get_group;
         $self->{seen}[1] = new  Gtk2::RadioButton($seenGroup,$parent->{lang}->{SearchSeenNo});
@@ -540,26 +608,34 @@ use Gtk2;
  		$hboxSeen->pack_start($self->{seen}[0],0,0,10);
 		$hboxSeen->pack_start($self->{seen}[1],0,0,10);
 		$hboxSeen->pack_start($self->{seen}[2],0,0,10);
-        $table->attach($labelSeen, 0, 1, 9, 10, 'fill', 'fill', 0, 0);
-        $table->attach($hboxSeen, 1, 2, 9, 10, 'fill', 'fill', 0, 0);
+        $table->attach($labelSeen, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($hboxSeen, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+        
+        $row++;
         
         my $ratingLabel = new Gtk2::Label($parent->{lang}->{SearchRating});
         $ratingLabel->set_alignment(0,0.5);
         my  $adj = Gtk2::Adjustment->new(0, 0, 10, 1, 1, 0) ;
         $self->{rating} = Gtk2::SpinButton->new($adj, 0, 0);
+        $self->{rating}->set_numeric(1);
         $self->{rating}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($ratingLabel, 0, 1, 10, 11, 'fill', 'fill', 0, 0);
-        $table->attach($self->{rating}, 1, 2, 10, 11, 'fill', 'expand', 0, 0);
+        $table->attach($ratingLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{rating}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
 
-        $table->attach(Gtk2::HSeparator->new, 0, 2, 11, 12, 'fill', 'fill', 0, 0);
+        $row++;
+
+        $table->attach(Gtk2::HSeparator->new, 0, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
         
-        my $borrowerLabel = new Gtk2::Label($parent->{lang}->{PanelBorrower});
+        $row++;
+        
+        my $borrowerLabel = new Gtk2::Label($parent->{lang}->{Displayed}->{borrower});
+        $borrowerLabel->set_alignment(0,0.5);
         $self->{borrowerOption} = new Gtk2::OptionMenu();
         $self->{borrowerOption}->signal_connect('activate' => sub {$self->response('ok')} );
-        $table->attach($borrowerLabel, 0, 1, 12, 13, 'fill', 'fill', 0, 0);
-        $table->attach($self->{borrowerOption}, 1, 2, 12, 13, 'fill', 'expand', 0, 0);
+        $table->attach($borrowerLabel, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{borrowerOption}, 1, 2, $row, $row + 1, 'fill', 'expand', 0, 0);
         
-        $self->vbox->pack_start($table, 1, 1, 5);
+        $self->vbox->pack_start($table, 1, 1, 0);
         $self->vbox->show_all;
 
         bless ($self, $class);
