@@ -137,6 +137,12 @@ use strict;
         return $newPic;
     }
         
+    sub restorePicture
+    {
+        my $self = shift;
+        return $self->{saved}->{image};
+    }
+    
     sub initLists
     {
         my $self = shift;
@@ -167,9 +173,11 @@ use strict;
 
         $info->{audio} = $info->{savedAudio};
         $info->{subt} = $info->{savedSubt};
+        $info->{type} = $info->{savedType};
         delete $info->{savedAudio};
         delete $info->{audioencoding};
         delete $info->{savedSubt};
+        delete $info->{savedType};
         delete $info->{year};
 
         foreach (keys %{$self->{saved}})
@@ -234,6 +242,8 @@ use strict;
             $movie->{audio} =~ s/,([^ ])/, $1/g;
             $movie->{savedSubt} = $movie->{subt};
             $movie->{subt} =~ s/,([^ ])/, $1/g;
+            $movie->{savedType} = $movie->{type};
+            $movie->{type} =~ s/,([^ ])/, $1/g;
             $movie->{year} = GCUtils::extractYear($movie->{date});
 
             $body .= $self->getItem($movie, $idx);
