@@ -231,6 +231,7 @@ http://le-spektre.org',
         'ImportFieldsTip' => 'Elija los campos a importar',
         'ImportNewList' => 'Crear un nuevo listado',
         'ImportCurrentList' => 'Añadir al listado actual',
+        'ImportDropError' => 'Hubo un error abriendo al menos un fichero. Se recargará el listado anterior.',
 
         'FileOverwrite' => 'Este fichero existe. ¿Quiere sustituirlo?',
 
@@ -447,7 +448,7 @@ http://le-spektre.org',
             seen => 'Personal : Ya vista',
             number => 'Soporte : Número',
             rating => 'Personal : Nota',
-            format => 'Soporte : Géneros',
+            format => 'Soporte : Soporte',
             url => 'Ficha : URL',
             place => 'Soporte : Sitio',
             video => 'Detalles : Formato de video',
