@@ -276,6 +276,7 @@ http://le-spektre.org',
         'ImportFieldsTip' => 'Selectaţi câmpurile pe care le doriţi importate',
         'ImportNewList' => 'Creează o nouă colecţie',
         'ImportCurrentList' => 'Adaugă la colecţia curentă',
+        'ImportDropError' => 'A intervenit o eroare la deschiderea a cel puţin unui fişier. Listă precedentă va fi reîncărcată.',
 
         'FileOverwrite' => 'Acest fişier deja există. Doriţi să îl suprascrieţi?',
 
@@ -299,7 +300,7 @@ http://le-spektre.org',
         'PanelLendDateSelect' => 'Selectaţi o dată',
         'PanelReturned' => 'Film returnat',
         'PanelRemove' =>'Şterge',
-        'PanelClear' =>'Şterge',
+        'PanelClear' =>'Şterge tot',
         'PanelReturnDate' => 'Data returnării',
         'PanelWeb' => 'Mai multe informaţii',
         'PanelWebTip' => 'Afişează informaţii de pe web despre acest film',
