@@ -27,7 +27,7 @@ use utf8;
 use strict;
 use Gtk2;
 
-my $VERSION = '6.0';
+my $VERSION = '6.1';
 
 {
     package GCMovieWindow;
@@ -862,7 +862,7 @@ my $VERSION = '6.0';
     {
         my ($self, $file) = @_;
   
-        $file =~ s/^file:\/\/(.*)\W*$/$1/;
+        $file =~ s/^file:\/\/\/?(.*)\W*$/$1/;
         $file =~ s/.$//ms;
         #(my $suffix = $file) =~ s/.*\.(\w+)\W*$/$1/;
         
@@ -881,9 +881,10 @@ my $VERSION = '6.0';
                 $options{lang} = $self->{lang};
                 $importer->process(\%options);
                 $self->restoreCursor;
-                return;
+                return 1;
             }
         }
+        return 0;
     }
 
     sub optionsError
@@ -1866,27 +1867,64 @@ my $VERSION = '6.0';
        
         #$splash->setProgress(0.06) if $splash;
 
-        $self->drag_dest_set('all', ["copy","private","default","move","link","ask"]);
+        $self->drag_dest_set('all', ['copy','private','default','move','link','ask']);
 
         $self->signal_connect(drag_data_received => \&drop_handler);
 
         my $target_list = Gtk2::TargetList->new();
-        my $atom1 = Gtk2::Gdk::Atom->new("text/uri-list");
-        my $atom2 = Gtk2::Gdk::Atom->new("text/plain");
+        my $atom1 = Gtk2::Gdk::Atom->new('text/uri-list');
+        my $atom2 = Gtk2::Gdk::Atom->new('text/plain');
         $target_list->add($atom1, 0, 0);
         $target_list->add($atom2, 0, 0);
-
+        if ($^O =~ /win32/i)
+        {
+            my $atom3 = Gtk2::Gdk::Atom->new('DROPFILES_DND');
+            $target_list->add($atom3, 0, 0);
+        }
+        
         $self->drag_dest_set_target_list($target_list);
 
         sub drop_handler {
-            my ($treeview, $context, $widget_x, $widget_y, $data, $info,$time) = @_;
+            my ($widget, $context, $widget_x, $widget_y, $data, $info,$time) = @_;
             my $type = $data->type->name;
-            if ($type eq 'text/uri-list')
+            if (($type eq 'text/uri-list')
+             || ($type eq 'DROPFILES_DND'))
             {
-                $self->newList;
                 my @files = split /\n/, $data->data;
-                $self->importWithDetect($_) foreach @files;
-                $self->{movies}->setStatus;
+                my $numbers = scalar @files;
+                $numbers-- if ($files[$#files] =~ /^\W*$/);
+                if (($numbers == 1)
+                 && ($files[0] =~ /\.gcf.?$/))
+                {
+                    #Special case when only one .gcf file is dropped
+                    (my $fileName = $files[0]) =~ s/^file:\/\/\/?(.*)\W*$/$1/;
+                    $fileName =~ s/.$//ms;
+                    $self->openMovie($fileName);
+                }
+                else
+                {
+                    my $fileName = $self->{options}->file;
+                    $self->newList;
+                    foreach (@files)
+                    {
+                        if (!$self->importWithDetect($_))
+                        {
+                            my $dialog = Gtk2::MessageDialog->new($self,
+							    [qw/modal destroy-with-parent/],
+							    'error',
+							    'ok',
+							    $self->{lang}->{ImportDropError});
+
+                            $dialog->set_position('center-on-parent');
+                            my $response = $dialog->run;
+                            $dialog->destroy;
+
+                            $self->openMovie($fileName);
+                            last;
+                        }
+                    }
+                    $self->{movies}->setStatus;
+                }
             }
             elsif ((my $url = $data->data) =~ m/^http:\/\//)
             {
