@@ -1075,27 +1075,51 @@ use strict;
         $self->{tooltips}->set_tip($self->{imgButton}, $parent->{lang}->{PanelImageTip});
         $self->{imgContext} = new Gtk2::Menu;
         $self->{imgContext}->append(Gtk2::TearoffMenuItem->new());
-        my $itemClear = Gtk2::ImageMenuItem->new_from_stock('gtk-clear',undef);
-        $itemClear->signal_connect("activate" , sub {
-            $self->clearImage;
-        });
-        $self->{imgContext}->append($itemClear);
-        my $itemOpen = Gtk2::ImageMenuItem->new_from_stock('gtk-open',undef);
-        $itemOpen->signal_connect("activate" , sub {
+        $self->{imgOpen} = Gtk2::ImageMenuItem->new_from_stock('gtk-open',undef);
+        $self->{imgOpen}->signal_connect("activate" , sub {
             $self->changeImage;
         });
-        $self->{imgContext}->append($itemOpen);
+        $self->{imgContext}->append($self->{imgOpen});
+        my $itemShow = Gtk2::ImageMenuItem->new_from_stock('gtk-zoom-100',undef);
+        $itemShow->signal_connect("activate" , sub {
+            $self->showImage;
+        });
+        $self->{imgContext}->append($itemShow);
+        $self->{imgClear} = Gtk2::ImageMenuItem->new_from_stock('gtk-clear',undef);
+        $self->{imgClear}->signal_connect("activate" , sub {
+            $self->clearImage;
+        });
+        $self->{imgContext}->append($self->{imgClear});
         $self->{imgContext}->show_all;
         $self->{imgButton}->signal_connect('clicked' => sub {
             $self->changeImage
         });
         $self->{imgButton}->signal_connect('button_press_event' => sub {
             my ($widget, $event) = @_;
-            return 0 if $self->{locked} || ($event->button ne 3);
+            #return 0 if $self->{locked} || ($event->button ne 3);
+            return 0 if ($event->button ne 3);
             $self->{imgContext}->popup(undef, undef, undef, undef, $event->button, $event->time);
             return 0;
         });
 
+        $self->{imgButton}->drag_dest_set('all', ['copy','private','default','move','link','ask']);
+        my $target_list = Gtk2::TargetList->new();
+        my $atom1 = Gtk2::Gdk::Atom->new('text/uri-list');
+        $target_list->add($atom1, 0, 0);
+        if ($^O =~ /win32/i)
+        {
+            my $atom2 = Gtk2::Gdk::Atom->new('DROPFILES_DND');
+            $target_list->add($atom2, 0, 0);
+        }
+        $self->{imgButton}->drag_dest_set_target_list($target_list);
+        $self->{imgButton}->signal_connect(drag_data_received => sub {
+            my ($widget, $context, $widget_x, $widget_y, $data, $info,$time) = @_;        
+            my @files = split /\n/, $data->data;
+            (my $fileName = $files[0]) =~ s/^file:\/\/\/?(.*)\W*$/$1/;
+            $fileName =~ s/.$//ms;
+            $self->changeImage($fileName);
+        });
+
         $self->{infosFrame} = new Gtk2::Frame($parent->{lang}->{PanelInfoFrame});
 
         $self->{dateLabel} = new Gtk2::Label($parent->{lang}->{Panel}->{date});
@@ -1626,6 +1650,11 @@ use strict;
 		  $self->{$button.'Button'}->show;
 		}
 		
+		for my $menu('Open', 'Clear')
+		{
+		  $self->{'img'.$menu}->set_sensitive(!$locked);
+		}		
+		
 		$self->checkBorrowerButtons;
 
         $self->{vboxAudio}->set_sensitive(!$locked);
@@ -1804,36 +1833,53 @@ use strict;
 
     sub changeImage
     {
-		my $self = shift;
+        my ($self, $fileName) = @_;
 
         return 0 if $self->{locked};
 
-        if (! $self->{imageDialog})
+        if (!$fileName)
         {
-            $self->{imageDialog} = GCFileChooserDialog->new($self->{parent}->{lang}->{PanelImageTitle}, $self->{parent}, 'open');
-            $self->{imageDialog}->setWithImagePreview(1);    
+            if (! $self->{imageDialog})
+            {
+                $self->{imageDialog} = GCFileChooserDialog->new($self->{parent}->{lang}->{PanelImageTitle}, $self->{parent}, 'open');
+                $self->{imageDialog}->setWithImagePreview(1);    
+            }
+
+            $self->{imageDialog}->set_filename($self->{imageFile});
+            my $response = $self->{imageDialog}->run;
+            $self->{imageDialog}->hide;
+            $self->showMe;
+            if ($response eq 'ok')
+            {
+                $fileName = $self->{imageDialog}->get_filename;
+            }
+            else
+            {
+                return;
+            }
         }
 
-		$self->{imageDialog}->set_filename($self->{imageFile});
-		my $response = $self->{imageDialog}->run;
-		if ($response eq 'ok')
-		{
-	        if ($self->{imageDialog}->get_filename ne $self->{imageFile})
+        if ($fileName ne $self->{imageFile})
+        {
+            my $imagePrefix = $self->{parent}->{imagePrefix};
+            if ($self->{imageFile} =~ /(\/|\\)$imagePrefix[0-9]*\./)
             {
-                my $imagePrefix = $self->{parent}->{imagePrefix};
-                if ($self->{imageFile} =~ /(\/|\\)$imagePrefix[0-9]*\./)
-                {
-                    $self->{parent}->{movies}->markToBeRemoved($self->{imageFile});
-                }
+                $self->{parent}->{movies}->markToBeRemoved($self->{imageFile});
             }
-            my $image = $self->{parent}->transformPicturePath($self->{imageDialog}->get_filename);
-            my $previous = $self->getAsHash;
-            $self->image($image);
-            my $new = $self->getAsHash;
-            $self->{parent}->{moviesList}->changeCurrent($previous, $new);
         }
-        $self->{imageDialog}->hide;
-        $self->showMe;
+        my $image = $self->{parent}->transformPicturePath($fileName);
+        my $previous = $self->getAsHash;
+        $self->image($image);
+        my $new = $self->getAsHash;
+        $self->{parent}->{moviesList}->changeCurrent($previous, $new);
+    }
+    
+    sub showImage
+    {
+        my $self = shift;
+        my $dialog = new GCImageDialog($self->{parent}, $self->{imageFile});
+        $dialog->show;
+        $dialog->destroy;
     }
     
     sub changeTrailer
