@@ -687,21 +687,15 @@
         Gtk2->main_iteration while (Gtk2->events_pending);
         my $tmpFile = mktemp('/tmp/gcfilmsXXXXXX');
         
-        my $dialog = new Gtk2::Dialog($self->{parent}->{lang}->{ImportViewPicture},
-                                                       $self,
-                                                       [qw/modal destroy-with-parent/],
-                                                       'gtk-ok' => 'ok',
-                                             );
-                                             
         my $browser = LWP::UserAgent->new;
         $browser->proxy(['http'], $self->{parent}->{options}->proxy);
         $browser->agent($self->{parent}->{agent});
         $browser->get($self->{info}->{image}, ':content_file' => $tmpFile);
-        my $image = Gtk2::Image->new_from_file($tmpFile);
-        $dialog->vbox->pack_start($image,0,0,0);
-        $dialog->vbox->show_all;
+        
+        my $dialog = new GCImageDialog($self, $tmpFile);
+        
         $self->window->set_cursor(Gtk2::Gdk::Cursor->new('left_ptr'));
-        $dialog->run;
+        $dialog->show;
         $dialog->destroy;
         unlink $tmpFile;
     }
