@@ -150,8 +150,9 @@ use GCPlugins::GCPluginsBase;
             elsif ($origtext =~ m/Genre :/)
             {
                 $origtext =~ s/Genre :(.*)/$1/;
-								$origtext = $self->capWord($origtext);
+                $origtext = $self->capWord($origtext);
                 $origtext  =~ s/ \/ /,/g;
+                $origtext  =~ s/,Video//g;
                 $self->{curInfo}->{type} = $origtext if !$self->{curInfo}->{type};
             }
             elsif ($origtext =~ m/Année du film :/)
@@ -186,20 +187,25 @@ use GCPlugins::GCPluginsBase;
     {
         my ($self, $html) = @_;
 
-				#Fix for character-encoding:
-				$html =~ s//'/g;
-				$html =~ s//\.\.\./g;
+        #Fix for character-encoding:
+        $html =~ s//'/g;
+        $html =~ s//\.\.\./g;
+        #'
 
         $html =~ s/<br>/\[br\]/gi;
         $html =~ s/&nbsp;/ /g;
         $html =~ s/<u>|<\/u>|<b>|<\/b>|<i>|<\/i>//gi;
         $html =~ s/<SPAN class="(?:tx12gris6|tx12noir)">([^<]*)<\/SPAN>/$1/gi;
-        $html =~ s/<A href="\/-\/Liste\/DVD\/mot_real_nomprenom=[^\/]*\/[^\/]*\/\?id=[0-9]*&donnee_appel=ALAPAGE" class="roll">([^<]*)<\/A>/<div class="realisateur">$1<\/div>/gi;
-        $html =~ s/<A href="\/-\/Liste\/DVD\/mot_art_nomprenom=[^\/]*\/[^\/]*\/\?id=[0-9]*&donnee_appel=ALAPAGE" class="roll">([^<]*)<\/A>/<div class="acteurs">$1<\/div>/gi;
-			  $html =~ s/<A href="http\:\/\/www\.alapage\.com\/-\/Liste\/DVD\/mot_(?:art_nomprenom|real_nomprenom|gen_libelle)=[^\/]*\/\?id=[0-9]*&donnee_appel=ALAPAGE[^"]*?" class="roll">([^<]*)<\/A>/$1/gi;
+        $html =~ s|<A href="/-/Liste/DVD/mot_real_nomprenom=.*?\?id=[0-9]*&donnee_appel=ALAPAGE" class="roll">([^<]*)</A>|<div class="realisateur">$1</div>|gi;
+        $html =~ s|<A href="/-/Liste/DVD/mot_art_nomprenom=.*?\?id=[0-9]*&donnee_appel=ALAPAGE" class="roll">([^<]*)</A>|<div class="acteurs">$1</div>|gi;
+        $html =~ s/<A href="http\:\/\/www\.alapage\.com\/-\/Liste\/DVD\/mot_(?:art_nomprenom|real_nomprenom|gen_libelle)=[^\/]*\/\?id=[0-9]*&donnee_appel=ALAPAGE[^"]*?" class="roll">([^<]*)<\/A>/$1/gi;
+        #"
+        $html =~ s|<A .*?mot_gen_libelle=.*?>(.*?)</A>|$1|gi;
         $html =~ s/<TD valign="top" class="tx12noir[^"]*">([^<]*)<\/TD>[^<]*<TD>([^<]*)<\/TD>/<td>$1 $2<\/td>/gi;
         $html =~ s/<td class="tx12grisbold" align="center" bgcolor="\#E6E6E8">([^<]*)<\/td>[^<]*<TD width="2"><IMG src="\/turbo\/templates\/img\/pix\.gif" width="2" height="25" border="0" alt=""><\/TD>[^<]*<td class="tx10noir" align="center" bgcolor="\#F4F4F6" colspan="3">([0-9]* mn)<\/td>/<td>$1 $2<\/td>/gi;
 
+        print "$html\n" if $self->{parsingList};
+
         return $html;
     }
     
