@@ -54,42 +54,39 @@ use GCPlugins::GCPluginsBase;
         {
             if ($tagname eq "a")
             {
-							if ($attr->{href} =~ m/animedb\.pl\?show=anime&aid=[0-9]*/)
-							{
-									$self->{isMovie} = 1;
-              		$self->{isInfo} = 1;
-              		$self->{movieIdx}++ if ($self->{movieIdx} < 0) || ($attr->{href} ne $self->{movieList}[$self->{movieIdx}]->{"url"});
-              		$self->{movieList}[$self->{movieIdx}]->{'url'} = $attr->{href};
-							}
-						}
-						elsif ($tagname eq "td")
-						{
-							if ($attr->{align} eq "center")
-							{
-								$self->{couldBeYear} = 1;
-							}
-							elsif ($attr->{class} eq "adbhead")
-							{
-								$self->{insideHeadline} = 1;
-							}
-						}
+                if ($attr->{href} =~ m/animedb\.pl\?show=anime&aid=[0-9]*/)
+                {
+                    $self->{isMovie} = 1;
+                    $self->{isInfo} = 1;
+                    $self->{movieIdx}++ if ($self->{movieIdx} < 0) || ($attr->{href} ne $self->{movieList}[$self->{movieIdx}]->{"url"});
+                    $self->{movieList}[$self->{movieIdx}]->{'url'} = $attr->{href};
+                }
+            }
+            elsif ($tagname eq "td")
+            {
+                $self->{couldBeYear} = 1 if ($attr->{align} eq "center");
+            }
+            elsif ($tagname eq "h1")
+            {
+                $self->{insideHeadline} = 1;
+            }
         }
         else
         {
-						if ($tagname eq "img")
-						{
-							if (($attr->{src} =~ m/http\:\/\/img2\.anidb\.info\/pics\/anime\/[0-9]*\.jpg/) && ($attr->{border} eq "0"))
-							{
-								$self->{curInfo}->{image} = $attr->{src} if !$self->{curInfo}->{image};
-							}
-						}
-						elsif ($tagname eq "div")
-						{
-							if ($attr->{class} eq "synopsis")
-							{
-								$self->{insideSynopsis} = 1;
-							}
-						}
+            if ($tagname eq "img")
+            {
+                if (($attr->{src} =~ m/http\:\/\/img[0-9]\.anidb\.info\/pics\/anime\/[0-9]*\.jpg/) && ($attr->{border} eq "0"))
+                {
+                    $self->{curInfo}->{image} = $attr->{src} if !$self->{curInfo}->{image};
+                }
+            }
+            elsif ($tagname eq "div")
+            {
+                if ($attr->{class} eq "synopsis")
+                {
+                    $self->{insideSynopsis} = 1;
+                }
+            }
         }
     }
 
@@ -105,13 +102,14 @@ use GCPlugins::GCPluginsBase;
         my ($self, $origtext) = @_;
 
         return if ($self->{parsingEnded});
-           
+
         if ($self->{parsingList})
         {
-						if ($self->{insideHeadline})
-						{
-							$self->{parsingEnded} = 1 if $origtext !~ m/Anime List - Search for:/;
-						}
+            if ($self->{insideHeadline})
+            {
+                $self->{parsingEnded} = 1 if $origtext !~ m/Anime List - Search for:/;
+                $self->{insideHeadline} = 0;
+            }
 
             if ($self->{isMovie})
             {
@@ -122,29 +120,40 @@ use GCPlugins::GCPluginsBase;
             }
             elsif ($self->{couldBeYear})
             {
-                $self->{movieList}[$self->{movieIdx}]->{"year"} = $origtext if $origtext =~ m/^ [0-9]{4} $/;
+                $self->{movieList}[$self->{movieIdx}]->{"year"} = $origtext if $origtext =~ m/^ [0-9]{4}(-[0-9]{4})? $/;
                 $self->{couldBeYear} = 0;
             }
         }
         else
         {
-						if ($self->{insideSynopsis})
-						{
-								($self->{curInfo}->{synopsis} = $origtext) =~ s/\s{2,}/ /g;
-								$self->{insideSynopsis} = 0;
-						}
-						elsif ($self->{inside}->{div})
-						{
-	         			$self->{curInfo}->{title} = $1 if $origtext =~ m/Title: (.*) /;
-	         			$self->{curInfo}->{orig} = $1 if $origtext =~ m/(?:Jap. Kanji|English): (.*) /;
-	         			$self->{curInfo}->{date} = $1 if $origtext =~ m/Year: (.*)/;
-	         			$self->{curInfo}->{director} = $1 if $origtext =~ m/Companies: (.*) /;
-	         			if ($origtext =~ m/Genre: (.*)/)
-								{
-									$self->{curInfo}->{type} = $1;
-									$self->{curInfo}->{type} =~ s/ - //;
-								}
-						}
+            if ($self->{insideSynopsis})
+            {
+                ($self->{curInfo}->{synopsis} = $origtext) =~ s/\s{2,}/ /g;
+                $self->{curInfo}->{synopsis} =~ s|GCBRGC|<br>|g;
+                $self->{curInfo}->{synopsis} =~ s/^\s*//;
+                $self->{insideSynopsis} = 0;
+            }
+            elsif ($self->{inside}->{div})
+            {
+                $self->{curInfo}->{title} = $1 if $origtext =~ m/Title: (.*) /;
+                if ($origtext =~ m/(?:Jap. Kanji|English): (.*) /)
+                {
+                    #print "Before : $1\n";
+                    #my $text = pack "U0C*", unpack "C*", $1;
+                    #print "After 1 : $text\n";
+                    #$text = Encode::encode_utf8($text);
+                    #print "After 2 : $text\n";
+                    #$self->{curInfo}->{orig} = Encode::encode('UTF-8', $1);
+                    $self->{curInfo}->{orig} = $1;
+                }
+                $self->{curInfo}->{date} = $1 if $origtext =~ m/Year: (.*)/;
+                $self->{curInfo}->{director} = $1 if $origtext =~ m/Companies: (.*) /;
+                if ($origtext =~ m/Genre: (.*)/)
+                {
+                    $self->{curInfo}->{type} = $1;
+                    $self->{curInfo}->{type} =~ s/ - //;
+                }
+            }
         }
     } 
 
@@ -167,16 +176,30 @@ use GCPlugins::GCPluginsBase;
     {
         my ($self, $html) = @_;
 
+        #use Compress::Zlib;
+
+        #my $html = Compress::Zlib::memGunzip($html);
+
         $self->{parsingEnded} = 0;
 
         $html =~ s/<a href="animedb\.pl\?show=producer&prid=[0-9]*" title="[^"]*">([^<]*)<\/a>/$1/g;
+        #"
         $html =~ s/<a href="animedb\.pl\?show=genre" target="_blank">(Genre:)<\/a>/$1/g;
         $html =~ s/<a href="animedb\.pl\?show=animelist&genid=[^"]*" title="[^"]*">([^<]*)<\/a>/$1/g;
         $html =~ s/ - <a href="animedb\.pl\?show=search&do\.search=1(&search\.anime.genre.[0-9]*=on){1,}" title="search for other animes with all of these genres">\[similar\]<\/a> //;
         $html =~ s/<td> ([^:]*): <\/td>\s*<td> ([^<]*) ?<\/td>/<div>$1: $2<\/div>/g;
-        $html =~ s/<br \/>//g;
+        $html =~ s/<br \/>/GCBRGC/g;
         $html =~ s/<b>Awards:<\/b><br><a href="[^"]*" target="_blank"><img src="[^"]*" border=0 alt="[^"]*" title="[^"]*"><\/a> <hr>//g;
-        $html =~ s/([^<]*<\/table>[^<]*<\/td>[^<]*<\/tr>[^<]*<\/table>[^<]*<\/td>[^<]*<\/tr>[^<]*<tr>[^<]*<td>\s*)([^<]*)(<\/td>[^<]*<\/tr>[^<]*<\/table>[^<]*<hr>[^<]*<table border=0>[^<]*<tr>[^<]*<td bgcolor="#b0b0b0">[^<]*<b>Group&nbsp;Info:<\/b>[^<]*<\/td>[^<]*<td bgcolor="#b0b0b0"> Group <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Last Ep <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> State <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Last Update <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Rating <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Cmts <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Action <\/td>[^<]*<\/tr>)/$1<div class="synopsis">$2<\/div>$3/m;
+        #$html =~ s/([^<]*<\/table>[^<]*<\/td>[^<]*<\/tr>[^<]*<\/table>[^<]*<\/td>[^<]*<\/tr>[^<]*<tr>[^<]*<td>\s*)([^<]*)(<\/td>[^<]*<\/tr>[^<]*<\/table>[^<]*<hr>[^<]*<table border=0>[^<]*<tr>[^<]*<td bgcolor="#b0b0b0">[^<]*<b>Group&nbsp;Info:<\/b>[^<]*<\/td>[^<]*<td bgcolor="#b0b0b0"> Group <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Last Ep <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> State <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Last Update <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Rating <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Cmts <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Action <\/td>[^<]*<\/tr>)/$1<div class="synopsis">$2<\/div>$3/m;
+        #$html =~ s/([^<]*)(<\/td>[^<]*<\/tr>[^<]*<\/table>[^<]*<hr>[^<]*<table border=0>[^<]*<tr>[^<]*<td bgcolor="#b0b0b0">[^<]*<b>Group&nbsp;Info:<\/b>[^<]*<\/td>[^<]*<td bgcolor="#b0b0b0"> Group <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Last Ep <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> State <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Last Update <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Rating <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Cmts <\/td>[^<]*<td bgcolor="#b0b0b0" align="center"> Action <\/td>[^<]*<\/tr>)/$1<div class="synopsis">$1<\/div>$2/m;
+
+        #Removed italic strings (useful for synopsis source)
+        $html =~ s|<i>(.*?)</i>|$1|g;
+        #Extract synopsis
+        $html =~ s|<td>([^<]*?)</td>\s*?</tr>\s*?</table>\s*?<hr>|<div class="synopsis">$1</div>|ms;
+        
+        #Remove Headline tag
+        $html =~ s/>\W*?<!-- headline -->/>/;
 
         return $html;
     }
@@ -214,6 +237,19 @@ use GCPlugins::GCPluginsBase;
     {
         return 'EN';
     }
+    
+#    sub getCharset
+#    {
+#        my $self = shift;
+#    
+#        return "UTF-8";
+#    }
+
+    sub getNotConverted
+    {
+        my $self = shift;
+        return ['orig'];
+    }
 
     sub hasSearchActors
     {
