@@ -68,10 +68,28 @@ use GCPlugins::GCPluginsBase;
         {
             if ($tagname eq "img")
             {
-                $self->{curInfo}->{image} = $attr->{src} if $attr->{alt} eq 'cover';
+                if ((
+                     ($self->{inside}->{a}) && 
+                     (($self->{currentHref} =~ m/photogallery/) || ($self->{currentHref} =~ m/posters/)) &&
+                     ($attr->{src} !~ /f\d{2}\.gif/)
+                   ) ||
+                   (
+                      (
+                        ($self->{curInfo}->{title}) &&
+                        ($attr->{alt} eq $self->{curInfo}->{title})
+                      ) ||
+                      (
+                        ($self->{curInfo}->{orig}) &&
+                        ($attr->{alt} eq $self->{curInfo}->{orig})
+                      )
+                   ))
+                {
+                    $self->{curInfo}->{image} = $attr->{src} if ! $self->{curInfo}->{image};
+                }
             }
             elsif ($tagname eq "a")
             {
+                $self->{currentHref} = $attr->{href};
                 if ($attr->{href} =~ m/fullcredits/)
                 {
                     $self->{insideActors} = 0;
@@ -179,7 +197,11 @@ use GCPlugins::GCPluginsBase;
             if ($self->{inside}->{h1})
             {
                 $self->{curInfo}->{date} = $origtext if $origtext =~ m/[0-9]+/;
-                $self->{curInfo}->{orig} = $origtext if !$self->{curInfo}->{orig};
+                if (!$self->{curInfo}->{orig})
+                {
+                    $self->{curInfo}->{orig} = $origtext;
+                    $self->{curInfo}->{orig} =~ s/\s*$//;
+                }
             }
             elsif ($self->{inside}->{b})
             {
@@ -216,6 +238,9 @@ use GCPlugins::GCPluginsBase;
         
         $self->{parsingEnded} = 0;
         
+        $html =~ s/"&#34;/'"/g;
+        $html =~ s/&#34;"/"'/g;
+        
         return $html;
     }
 
