@@ -29,7 +29,7 @@ use utf8;
     package GCPluginParser;
     use base qw(HTML::Parser);
     use LWP::Simple qw($ua get);
-    use URI::Escape;
+    use URI::Escape qw/uri_escape_utf8 uri_escape/;
     use HTML::Entities;
     use Encode;
 
@@ -74,15 +74,21 @@ use utf8;
         $self->{isInfo} = 0;
         $self->{movieList} = ();
 
-        my $word = uri_escape($self->{title});
+        #my $word = uri_escape_utf8($self->{title});
+        my $title2 = encode($self->getCharset, $self->{title});
+        my $word = uri_escape($title2);
         $word =~ s/%20/+/g;
+        my $i = 0;
 
         $self->{loadedUrl} = $self->getSearchUrl($word);
         my $html = get($self->{loadedUrl});
+
         $self->{parsingList} = 1;
         $html = $self->preProcess($html);
+
         decode_entities($html);
         $self->{inside} = undef;
+
         $self->parse($html);
         
         for my $i(0..$self->{movieIdx})
@@ -135,13 +141,21 @@ use utf8;
         return "ISO-8859-1";
     }
     
+    sub getNotConverted
+    {
+        my $self = shift;
+        return [];
+    }
+    
     sub convertCharset
     {
         my ($self, $string) = @_;
 
         my $result = $string;
 
-        $result = decode($self->getCharset, $result);
+        eval {
+            $result = decode($self->getCharset, $result);
+        };
 
         # FIXME: Without this, there are some problems on Mandrake
         #use Encode 'decode_utf8';
@@ -177,7 +191,6 @@ use utf8;
         $self->checkProxy;
         
         $url = $self->changeUrl($url);
-        
         my $html = get($url);
         $self->{parsingList} = 0;
         #$html = $self->convertCharset($html);
@@ -209,10 +222,12 @@ use utf8;
             $self->{curInfo}->{orig} = '';
         }        
 
+        my @noConversion = @{$self->getNotConverted};
         foreach (keys %{$self->{curInfo}})
         {
             next if $_ eq 'url';
-            $self->{curInfo}->{$_} = $self->convertCharset($self->{curInfo}->{$_});
+            $self->{curInfo}->{$_} = $self->convertCharset($self->{curInfo}->{$_})
+                if ! GCUtils::inArrayTest($_, @noConversion);
             $self->{curInfo}->{$_} =~ s/\|/,/gm;
             $self->{curInfo}->{$_} =~ s/\r//gm;
             $self->{curInfo}->{$_} =~ s/\s*$//gm;
@@ -237,4 +252,4 @@ use utf8;
     
 }
 
-1;
\ No newline at end of file
+1;
