@@ -168,6 +168,17 @@ sub inArray
     return undef;
 }
 
+sub inArrayTest
+{
+    my $val = shift;
+    my $elem;
+    foreach $elem(@_)
+    {
+        return 1 if($val eq $elem);
+    }
+    return 0;
+}
+
 my $rc_style = Gtk2::RcStyle->new;
 
 sub setWidgetPixmap
